summaryrefslogtreecommitdiffstats
path: root/khtml/xml/dom2_eventsimpl.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'khtml/xml/dom2_eventsimpl.cpp')
-rw-r--r--khtml/xml/dom2_eventsimpl.cpp40
1 files changed, 20 insertions, 20 deletions
diff --git a/khtml/xml/dom2_eventsimpl.cpp b/khtml/xml/dom2_eventsimpl.cpp
index 25e595baa..bcc2fca3a 100644
--- a/khtml/xml/dom2_eventsimpl.cpp
+++ b/khtml/xml/dom2_eventsimpl.cpp
@@ -48,7 +48,7 @@ EventImpl::EventImpl()
m_currentTarget = 0;
m_eventPhase = 0;
m_target = 0;
- m_createTime = TQDateTime::tqcurrentDateTime();
+ m_createTime = TQDateTime::currentDateTime();
m_defaultHandled = false;
}
@@ -67,7 +67,7 @@ EventImpl::EventImpl(EventId _id, bool canBubbleArg, bool cancelableArg)
m_currentTarget = 0;
m_eventPhase = 0;
m_target = 0;
- m_createTime = TQDateTime::tqcurrentDateTime();
+ m_createTime = TQDateTime::currentDateTime();
m_defaultHandled = false;
}
@@ -499,14 +499,14 @@ public:
}
L toLeft(R r) {
- TQMapIterator<R,L> i( m_rToL.tqfind(r) );
+ TQMapIterator<R,L> i( m_rToL.find(r) );
if (i != m_rToL.end())
return *i;
return L();
}
R toRight(L l) {
- TQMapIterator<L,R> i = m_lToR.tqfind(l);
+ TQMapIterator<L,R> i = m_lToR.find(l);
if (i != m_lToR.end())
return *i;
return R();
@@ -590,10 +590,10 @@ KeyEventBaseImpl::KeyEventBaseImpl(EventId id, bool canBubbleArg, bool cancelabl
m_keyVal = key->ascii();
m_virtKeyVal = virtKeyToQtKey()->toLeft(key->key());
// m_keyVal should contain the tqunicode value
// of the pressed key if available.
if (m_virtKeyVal == DOM_VK_UNDEFINED && !key->text().isEmpty())
- m_keyVal = key->text().tqunicode()[0];
+ m_keyVal = key->text().unicode()[0];
// key->state returns enum ButtonState, which is ShiftButton, ControlButton and AltButton or'ed together.
m_modifier = key->state();
@@ -739,18 +739,18 @@ DOMString KeyboardEventImpl::keyIdentifier() const
{
if (unsigned special = virtKeyVal())
if (const char* id = keyIdentifiersToVirtKeys()->toLeft(special))
- return TQString::tqfromLatin1(id);
+ return TQString::fromLatin1(id);
- if (unsigned tqunicode = keyVal())
- return TQString(TQChar(tqunicode));
+ if (unsigned unicode = keyVal())
+ return TQString(TQChar(unicode));
return "Unidentified";
}
bool KeyboardEventImpl::getModifierState (const DOMString& keyIdentifierArg) const
{
- unsigned tqmask = keyModifiersToCode()->toRight(keyIdentifierArg.string().latin1());
- return m_modifier & tqmask;
+ unsigned mask = keyModifiersToCode()->toRight(keyIdentifierArg.string().latin1());
+ return m_modifier & mask;
}
bool KeyboardEventImpl::isKeyboardEvent() const
@@ -773,9 +773,9 @@ void KeyboardEventImpl::initKeyboardEvent(const DOMString &typeArg,
//Figure out the code information from the key identifier.
if (keyIdentifierArg.length() == 1) {
//Likely to be normal tqunicode id, unless it's one of the few
//special values.
- unsigned short code = keyIdentifierArg.tqunicode()[0];
+ unsigned short code = keyIdentifierArg.unicode()[0];
if (code > 0x20 && code != 0x7F)
keyVal = code;
}
@@ -790,8 +790,8 @@ void KeyboardEventImpl::initKeyboardEvent(const DOMString &typeArg,
unsigned modifiers = 0;
for (TQStringList::Iterator i = mods.begin(); i != mods.end(); ++i)
- if (unsigned tqmask = keyModifiersToCode()->toRight((*i).latin1()))
- modifiers |= tqmask;
+ if (unsigned mask = keyModifiersToCode()->toRight((*i).latin1()))
+ modifiers |= mask;
initKeyBaseEvent(typeArg, canBubbleArg, cancelableArg, viewArg,
keyVal, virtKeyVal, modifiers);
@@ -819,7 +819,7 @@ int KeyboardEventImpl::keyCode() const
if (m_virtKeyVal != DOM_VK_UNDEFINED)
return m_virtKeyVal;
else
- return TQChar((unsigned short)m_keyVal).upper().tqunicode();
+ return TQChar((unsigned short)m_keyVal).upper().unicode();
}
int KeyboardEventImpl::charCode() const
@@ -856,14 +856,14 @@ void TextEventImpl::initTextEvent(const DOMString &typeArg,
//See whether we can get a key out of this.
unsigned keyCode = 0;
if (text.length() == 1)
- keyCode = text.tqunicode()[0].tqunicode();
+ keyCode = text.unicode()[0].unicode();
initKeyBaseEvent(typeArg, canBubbleArg, cancelableArg, viewArg,
keyCode, 0, 0);
}
int TextEventImpl::keyCode() const
{
//Mozilla returns 0 here unless this is a non-tqunicode key.
//IE stuffs everything here, and so we try to match it..
if (m_keyVal)
return m_keyVal;
@@ -872,8 +872,8 @@ int TextEventImpl::keyCode() const
int TextEventImpl::charCode() const
{
//On text events, in Mozilla charCode is 0 for non-tqunicode keys,
//and the tqunicode key otherwise... IE doesn't support this.
if (m_virtKeyVal)
return 0;
return m_keyVal;
@@ -590,10 +590,10 @@ KeyEventBaseImpl::KeyEventBaseImpl(EventId id, bool canBubbleArg, bool cancelabl
m_keyVal = key->ascii();
m_virtKeyVal = virtKeyToQtKey()->toLeft(key->key());
- // m_keyVal should contain the tqunicode value
+ // m_keyVal should contain the unicode value
// of the pressed key if available.
if (m_virtKeyVal == DOM_VK_UNDEFINED && !key->text().isEmpty())
@@ -773,9 +773,9 @@ void KeyboardEventImpl::initKeyboardEvent(const DOMString &typeArg,
//Figure out the code information from the key identifier.
if (keyIdentifierArg.length() == 1) {
- //Likely to be normal tqunicode id, unless it's one of the few
+ //Likely to be normal unicode id, unless it's one of the few
//special values.
@@ -856,14 +856,14 @@ void TextEventImpl::initTextEvent(const DOMString &typeArg,
int TextEventImpl::keyCode() const
{
- //Mozilla returns 0 here unless this is a non-tqunicode key.
+ //Mozilla returns 0 here unless this is a non-unicode key.
//IE stuffs everything here, and so we try to match it..
if (m_keyVal)
@@ -872,8 +872,8 @@ int TextEventImpl::keyCode() const
int TextEventImpl::charCode() const
{
- //On text events, in Mozilla charCode is 0 for non-tqunicode keys,
- //and the tqunicode key otherwise... IE doesn't support this.
+ //On text events, in Mozilla charCode is 0 for non-unicode keys,
+ //and the unicode key otherwise... IE doesn't support this.
if (m_virtKeyVal)
return 0;